<?php
// Error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start session if not already started
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

// Check if user is logged in
function isLoggedIn() {
    return isset($_SESSION['logged_in']) && $_SESSION['logged_in'] === true;
}

// Get current user ID
function getUserId() {
    return isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
}

// Get current user data
function getUserData($conn) {
    if (!isLoggedIn()) return null;
    
    $userId = getUserId();
    $query = "SELECT * FROM users WHERE id = ?";
    $stmt = mysqli_prepare($conn, $query);
    mysqli_stmt_bind_param($stmt, "i", $userId);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);
    
    return mysqli_fetch_assoc($result);
}

// Common functions
function sanitizeInput($data) {
    $sanitized = [];
    foreach ($data as $key => $value) {
        if (is_array($value)) {
            $sanitized[$key] = sanitizeInput($value);
        } else {
            $sanitized[$key] = htmlspecialchars(trim($value), ENT_QUOTES, 'UTF-8');
        }
    }
    return $sanitized;
}

function validateRegistrationForm($data) {
    $errors = [];
    
    // Validate required fields
    $requiredFields = [
        'first-name', 'last-name', 'dob', 'gender', 'email', 
        'confirm-email', 'phone', 'occupation', 'address', 
        'city', 'state', 'zip', 'password', 'confirm-password', 
        'citizen', 'terms'
    ];
    
    foreach ($requiredFields as $field) {
        if (empty($data[$field])) {
            $errors[] = ucfirst(str_replace('-', ' ', $field)) . " is required.";
        }
    }
    
    // Validate email format
    if (!filter_var($data['email'], FILTER_VALIDATE_EMAIL)) {
        $errors[] = "Invalid email format.";
    }
    
    // Check if emails match
    if ($data['email'] !== $data['confirm-email']) {
        $errors[] = "Email addresses do not match.";
    }
    
    // Validate password strength
    if (strlen($data['password']) < 8) {
        $errors[] = "Password must be at least 8 characters long.";
    }
    
    if (!preg_match('/[0-9]/', $data['password'])) {
        $errors[] = "Password must contain at least one number.";
    }
    
    if (!preg_match('/[^A-Za-z0-9]/', $data['password'])) {
        $errors[] = "Password must contain at least one special character.";
    }
    
    // Check if passwords match
    if ($data['password'] !== $data['confirm-password']) {
        $errors[] = "Passwords do not match.";
    }
    
    // Validate phone number
    if (!preg_match('/^[0-9]{10,}$/', preg_replace('/[^0-9]/', '', $data['phone']))) {
        $errors[] = "Invalid phone number format.";
    }
    
    // Validate date of birth
    if (!preg_match('/^\d{2}\/\d{2}\/\d{4}$/', $data['dob'])) {
        $errors[] = "Date of birth must be in MM/DD/YYYY format.";
    }
    
    // Validate zip code
    if (!preg_match('/^\d{5}(-\d{4})?$/', $data['zip'])) {
        $errors[] = "Invalid ZIP code format.";
    }
    
    return $errors;
}

function emailExists($email, $conn) {
    $query = "SELECT id FROM users WHERE email = ?";
    $stmt = mysqli_prepare($conn, $query);
    mysqli_stmt_bind_param($stmt, "s", $email);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);
    return mysqli_num_rows($result) > 0;
}

function registerUser($data, $hashedPassword, $conn) {
    // Prepare data for insertion
    $firstName = mysqli_real_escape_string($conn, $data['first-name']);
    $lastName = mysqli_real_escape_string($conn, $data['last-name']);
    $dob = mysqli_real_escape_string($conn, $data['dob']);
    $gender = mysqli_real_escape_string($conn, $data['gender']);
    $email = mysqli_real_escape_string($conn, $data['email']);
    $phone = mysqli_real_escape_string($conn, preg_replace('/[^0-9]/', '', $data['phone']));
    $occupation = mysqli_real_escape_string($conn, $data['occupation']);
    $address = mysqli_real_escape_string($conn, $data['address']);
    $city = mysqli_real_escape_string($conn, $data['city']);
    $state = mysqli_real_escape_string($conn, $data['state']);
    $zip = mysqli_real_escape_string($conn, $data['zip']);
    $citizen = ($data['citizen'] == 'yes') ? 1 : 0;
    $marketing = isset($data['marketing']) ? 1 : 0;
    $createdAt = date('Y-m-d H:i:s');
    
    // SQL query to insert user
    $query = "INSERT INTO users (
                first_name, last_name, dob, gender, email, phone, 
                occupation, address, city, state, zip, password, 
                is_citizen, accept_marketing, created_at
              ) VALUES (
                '$firstName', '$lastName', '$dob', '$gender', '$email', 
                '$phone', '$occupation', '$address', '$city', '$state', 
                '$zip', '$hashedPassword', $citizen, $marketing, '$createdAt'
              )";
    
    return mysqli_query($conn, $query);
}

function authenticateUser($email, $password, $conn) {
    $query = "SELECT id, email, password, first_name, last_name FROM users WHERE email = ?";
    $stmt = mysqli_prepare($conn, $query);
    mysqli_stmt_bind_param($stmt, "s", $email);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);
    
    if ($result && mysqli_num_rows($result) > 0) {
        $user = mysqli_fetch_assoc($result);
        if (password_verify($password, $user['password'])) {
            return $user;
        }
    }
    return false;
}

// Redirect if not logged in
function requireLogin() {
    if (!isLoggedIn()) {
        header("Location: login.php");
        exit();
    }
}


?>