<?php
// register.php
require_once 'connect.php';

$errors = [];
$success = false;

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize and validate inputs
    $firstName = sanitizeInput($_POST['first-name']);
    $lastName = sanitizeInput($_POST['last-name']);
    $dob = sanitizeInput($_POST['dob']);
    $gender = sanitizeInput($_POST['gender']);
    $email = filter_var($_POST['email'], FILTER_SANITIZE_EMAIL);
    $confirmEmail = filter_var($_POST['confirm-email'], FILTER_SANITIZE_EMAIL);
    $phone = sanitizeInput($_POST['phone']);
    $occupation = sanitizeInput($_POST['Occupation']);
    $address = sanitizeInput($_POST['address']);
    $city = sanitizeInput($_POST['city']);
    $state = sanitizeInput($_POST['state']);
    $zip = sanitizeInput($_POST['zip']);
    $password = $_POST['password'];
    $confirmPassword = $_POST['confirm-password'];
    $isUsCitizen = isset($_POST['citizen']) && $_POST['citizen'] === 'yes' ? 1 : 0;
    $agreedToTerms = isset($_POST['terms']) ? 1 : 0;
    $agreedToMarketing = isset($_POST['marketing']) ? 1 : 0;

    // Validation
    if (empty($firstName)) $errors[] = "First name is required";
    if (empty($lastName)) $errors[] = "Last name is required";
    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) $errors[] = "Invalid email format";
    if ($email !== $confirmEmail) $errors[] = "Emails do not match";
    if (strlen($password) < 8) $errors[] = "Password must be at least 8 characters";
    if (!preg_match("/[0-9]/", $password)) $errors[] = "Password must contain at least one number";
    if (!preg_match("/[^A-Za-z0-9]/", $password)) $errors[] = "Password must contain at least one special character";
    if ($password !== $confirmPassword) $errors[] = "Passwords do not match";
    if (!$agreedToTerms) $errors[] = "You must agree to the terms of service";

    // Check if email already exists
    $stmt = $pdo->prepare("SELECT email FROM users WHERE email = ?");
    $stmt->execute([$email]);
    if ($stmt->fetch()) $errors[] = "Email already registered";

    // If no errors, proceed with registration
    if (empty($errors)) {
        // Hash password
        $passwordHash = password_hash($password, PASSWORD_DEFAULT);

        // Convert date format from MM/DD/YYYY to YYYY-MM-DD for MySQL
        $dobFormatted = DateTime::createFromFormat('m/d/Y', $dob)->format('Y-m-d');

        try {
            $stmt = $pdo->prepare("INSERT INTO users 
                (first_name, last_name, dob, gender, email, phone, occupation, 
                 address, city, state, zip, password_hash, is_us_citizen, 
                 agreed_to_terms, agreed_to_marketing) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");

            $stmt->execute([
                $firstName, $lastName, $dobFormatted, $gender, $email, $phone, $occupation,
                $address, $city, $state, $zip, $passwordHash, $isUsCitizen,
                $agreedToTerms, $agreedToMarketing
            ]);

            $success = true;
            
            // Optionally log the user in immediately
            $_SESSION['user_id'] = $pdo->lastInsertId();
            $_SESSION['user_email'] = $email;
            
        } catch (PDOException $e) {
            $errors[] = "Registration failed: " . $e->getMessage();
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="icon" type="image/png" href="../wp-content/themes/trevor-base-theme/assets/Icon-Images/favicon.png">
    <title>Registration Form</title>
    <style>
        * {
            box-sizing: border-box;
            font-family: Arial, sans-serif;
        }
        
        body {
            margin: 0;
            padding: 0;
            color: #333;
            background-image: url('https://images.unsplash.com/photo-1451187580459-43490279c0fa?ixlib=rb-1.2.1&auto=format&fit=crop&w=1352&q=80');
            background-size: cover;
            background-position: center;
            background-attachment: fixed;
            background-repeat: no-repeat;
            position: relative;
            min-height: 100vh;
            display: flex;
            flex-direction: column;
        }
 
        .header {
            background-color: rgba(255, 255, 255, 0.2);
            padding: 20px 0;
            backdrop-filter: blur(10px);
            text-align: center;
            width: 100%;
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 15px 20px;
        }

        .logo {
            color: white;
            font-size: 2rem;
            font-weight: bold;
            text-shadow: 2px 2px 4px rgba(0, 0, 0, 0.5);
        }

        .logo img {
            height: 50px;
        }

        .login-button {
            padding: 8px 20px;
            background-color: #0073aa; /* example color - change as needed */
            color: white;
            text-decoration: none;
            border-radius: 4px;
            font-weight: bold;
        }

        .login-button:hover {
            background-color: #005a87; /* darker shade for hover */
        }

        body::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: rgba(255, 255, 255, 0);
            z-index: -1;
        }
        
        .container {
            max-width: 1000px;
            margin: 0 auto;
            padding: 20px;
            flex: 1;
        }
        
        .registration-form {
            background-color: #ffffffd1;
            border-radius: 8px;
            box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
            padding: 40px;
            margin: 30px auto;
        }
        
        .form-header {
            text-align: center;
            margin-bottom: 30px;
            background-image: linear-gradient(rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0.5)), url('../wp-content/themes/trevor-base-theme/assets/images/new-york.jpg');
            background-size: cover;
            background-position: center;
            padding: 30px 20px;
            border-radius: 8px 8px 0 0;
        }
               
        .form-header h1 {
            color: #0066cc;
            margin-bottom: 10px;
            font-size: 32px;
        }
        
        .form-header p {
            color: #ffffff;
            font-size: 16px;
        }
        
        .form-row {
            display: flex;
            flex-wrap: wrap;
            margin-bottom: 20px;
        }
        
        .form-group {
            flex: 1;
            min-width: 250px;
            margin-right: 15px;
            margin-bottom: 15px;
        }
        
        .form-group:last-child {
            margin-right: 0;
        }
        
        .form-group label {
            display: block;
            margin-bottom: 8px;
            font-weight: bold;
            color: #555;
        }
        
        .form-group input[type="text"],
        .form-group input[type="email"],
        .form-group input[type="tel"],
        .form-group input[type="password"],
        .form-group select,
        .form-group textarea {
            width: 100%;
            padding: 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 16px;
            transition: border-color 0.3s;
        }
        
        .form-group input[type="text"]:focus,
        .form-group input[type="email"]:focus,
        .form-group input[type="tel"]:focus,
        .form-group input[type="password"]:focus,
        .form-group select:focus,
        .form-group textarea:focus {
            border-color: #0066cc;
            outline: none;
            box-shadow: 0 0 5px rgba(0, 102, 204, 0.3);
        }
        
        .form-group input[type="checkbox"] {
            margin-right: 10px;
        }
        
        .form-group .checkbox-label {
            display: inline;
            font-weight: normal;
        }
        
        .form-submit {
            text-align: center;
            margin-top: 30px;
            width: 100%;
        }
        
        .form-submit button {
            background-color: #0066cc;
            color: white;
            border: none;
            padding: 14px 40px;
            font-size: 18px;
            border-radius: 4px;
            cursor: pointer;
            transition: all 0.3s;
        }
        
        .form-submit button:hover {
            background-color: #0052a3;
            transform: translateY(-2px);
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
        }
        
        .required-field::after {
            content: " *";
            color: red;
        }
        
        .password-requirements {
            font-size: 14px;
            color: #666;
            margin-top: 5px;
        }
        
        .disclaimer {
            font-size: 14px;
            text-align: center;
            color: #666;
            margin-top: 30px;
            padding-top: 20px;
            border-top: 1px solid #eee;
            line-height: 1.6;
        }

        .footer {
            background-color: slategrey;
            padding: 20px;
            text-align: center;
            color: white;
            width: 100%;
            margin-top: auto;
        }
        
        @media (max-width: 768px) {
            .form-group {
                flex: 100%;
                margin-right: 0;
            }
            
            .registration-form {
                padding: 25px;
            }
            
            .form-header h1 {
                font-size: 28px;
            }
            
            .form-submit {
                display: flex;
                justify-content: center;
            }
        }
        
        @media (max-width: 480px) {
            .container {
                padding: 10px;
            }
            
            .registration-form {
                padding: 20px;
                margin: 15px auto;
            }
            
            .form-header h1 {
                font-size: 24px;
            }
        }

        .error { color: red; }
        .success { color: green; }
    </style>
</head>
<body>
    <header class="header">
        <div class="logo">
            <a href="../front-page-121824/index.html">
                <img src="../wp-content/themes/trevor-base-theme/assets/images/USA-Legacy-Grant-Logo.png" alt="Website Logo">
            </a>
        </div>
        <div class="header-right">
            <a href="../Login/login.html" class="login-button">Member Login</a>
        </div>
    </header>
    
    <div class="container">
        <?php if (!empty($errors)): ?>
        <div class="error">
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <?php if ($success): ?>
        <div class="success">
            Registration successful! You can now <a href="login.php">log in</a>.
        </div>
    <?php else: ?>
        <!-- Your original form HTML goes here -->
        <form class="registration-form" action="register.php" method="post">
            <div class="form-header">
                <h1>Create an Account</h1>
                <p>Please fill in the information below to start your application.</p>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="first-name">First Name</label>
                    <input type="text" id="first-name" name="first-name" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="last-name">Last Name</label>
                    <input type="text" id="last-name" name="last-name" required>
                </div>
            </div>

            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="dob">Date of Birth</label>
                    <input type="text" id="dob" name="dob" placeholder="MM/DD/YYYY" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="gender">Gender</label>
                    <input type="text" id="gender" name="ssn" placeholder="Male or Female" required>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="email">Email Address</label>
                    <input type="email" id="email" name="email" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="confirm-email">Confirm Email Address</label>
                    <input type="email" id="confirm-email" name="confirm-email" required>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="phone">Phone Number</label>
                    <input type="tel" id="phone" name="phone" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="Occupation">Occupation</label>
                    <input type="text" id="Occupation" name="Occupation" required>
                </div>
            </div>
                                    
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="address">Home Address</label>
                    <input type="text" id="address" name="address" required>
                </div>
                                            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="city">City</label>
                    <input type="text" id="city" name="city" required>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="state">State</label>
    <select id="state" name="state" required>
        <option value="">Select State</option>
        <option value="AL">Alabama</option>
        <option value="AK">Alaska</option>
        <option value="AZ">Arizona</option>
        <option value="AR">Arkansas</option>
        <option value="CA">California</option>
        <option value="CO">Colorado</option>
        <option value="CT">Connecticut</option>
        <option value="DE">Delaware</option>
        <option value="FL">Florida</option>
        <option value="GA">Georgia</option>
        <option value="HI">Hawaii</option>
        <option value="ID">Idaho</option>
        <option value="IL">Illinois</option>
        <option value="IN">Indiana</option>
        <option value="IA">Iowa</option>
        <option value="KS">Kansas</option>
        <option value="KY">Kentucky</option>
        <option value="LA">Louisiana</option>
        <option value="ME">Maine</option>
        <option value="MD">Maryland</option>
        <option value="MA">Massachusetts</option>
        <option value="MI">Michigan</option>
        <option value="MN">Minnesota</option>
        <option value="MS">Mississippi</option>
        <option value="MO">Missouri</option>
        <option value="MT">Montana</option>
        <option value="NE">Nebraska</option>
        <option value="NV">Nevada</option>
        <option value="NH">New Hampshire</option>
        <option value="NJ">New Jersey</option>
        <option value="NM">New Mexico</option>
        <option value="NY">New York</option>
        <option value="NC">North Carolina</option>
        <option value="ND">North Dakota</option>
        <option value="OH">Ohio</option>
        <option value="OK">Oklahoma</option>
        <option value="OR">Oregon</option>
        <option value="PA">Pennsylvania</option>
        <option value="RI">Rhode Island</option>
        <option value="SC">South Carolina</option>
        <option value="SD">South Dakota</option>
        <option value="TN">Tennessee</option>
        <option value="TX">Texas</option>
        <option value="UT">Utah</option>
        <option value="VT">Vermont</option>
        <option value="VA">Virginia</option>
        <option value="WA">Washington</option>
        <option value="WV">West Virginia</option>
        <option value="WI">Wisconsin</option>        
        <option value="WY">Wyoming</option>
    </select>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="zip">Zip Code</label>
                    <input type="text" id="zip" name="zip" required>
                </div>
            </div>

                                 
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field" for="password">Password</label>
                    <input type="password" id="password" name="password" required>
                    <div class="password-requirements">
                        Password must be at least 8 characters long and contain at least one number and one special character.
                    </div>
                </div>
                
                <div class="form-group">
                    <label class="required-field" for="confirm-password">Confirm Password</label>
                    <input type="password" id="confirm-password" name="confirm-password" required>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <label class="required-field">Are you a U.S. Citizen?</label>
                    <div>
                        <input type="radio" id="citizen-yes" name="citizen" value="yes" required>
                        <label class="checkbox-label" for="citizen-yes">Yes</label>
                        
                        <input type="radio" id="citizen-no" name="citizen" value="no">
                        <label class="checkbox-label" for="citizen-no">No</label>
                    </div>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <input type="checkbox" id="terms" name="terms" required>
                    <label class="checkbox-label required-field" for="terms">
                        I agree to the <a href="/terms-of-service">Terms of Service</a> and 
                        <a href="/privacy-policy" style="color: blue;">Privacy Policy</a>
                    </label>
                </div>
            </div>
            
            <div class="form-row">
                <div class="form-group">
                    <input type="checkbox" id="marketing" name="marketing">
                    <label class="checkbox-label" for="marketing">I agree to receive marketing communications</label>
                </div>
            </div>
            
            <div class="form-submit">
                <button type="submit">Submit</button>
            </div>
            
            <div class="disclaimer">
                <p>By creating an account, you agree to our Terms of Service and acknowledge that you have read our Privacy Policy. Your information will be used in accordance with our Privacy Policy.</p>
            </div>
        </form>
        <?php endif; ?>
    </div>
    <footer class="footer">
        &copy; <span id="year"></span> USA Legacy Grant. All Rights Reserved. | <a href="#">Privacy Policy</a>
    </footer>

    <script>
        document.getElementById("year").textContent = new Date().getFullYear();
    </script>
</body>
</html>